@@ -1,7 +1,7 @@
 // #![feature(type_alias_impl_trait)]
 // #![feature(box_syntax)]
 #![forbid(missing_debug_implementations)]
-#![forbid(missing_crate_level_docs)]
+#![forbid(rustdoc::missing_crate_level_docs)]
 #![doc = include_str!("../Readme.md")]
 #![doc(html_logo_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
 #![doc(html_favicon_url = "https://upload.wikimedia.org/wikipedia/commons/d/d5/Tailwind_CSS_Logo.svg")]
